@@ -14,12 +14,14 @@ class PasswordLineEditTest : public QObject
     Q_OBJECT
 public:
     explicit PasswordLineEditTest(QObject *parent = nullptr);
-    ~PasswordLineEditTest() = default;
+    ~PasswordLineEditTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldShowTogglePassword();
     void shouldNotShowToggleWhenSetPassword();
     void shouldShowRevealPassword();
+    void shouldEmitSignalPasswordChanged();
+    void testReadOnly();
 };
 
 #endif
